@@ -7,15 +7,13 @@ RSpec.configure do |c|
   c.include PuppetlabsSpec::Files
 
   c.before :each do
-    # Ensure that we don't accidentally cache facts and environment
-    # between test cases.
-    Facter::Util::Loader.any_instance.stubs(:load_all)
-    Facter.clear
-    Facter.clear_messages
-
     # Store any environment variables away to be restored later
     @old_env = {}
     ENV.each_key {|k| @old_env[k] = ENV[k]}
+
+    if ENV['STRICT_VARIABLES'] == 'yes'
+      Puppet.settings[:strict_variables]=true
+    end
   end
 
   c.after :each do
@@ -28,3 +26,6 @@ end
 def param(type, title, param)
   param_value(catalogue, type, title, param)
 end
+
+# With rspec-puppet v2.0 this allows coverage checks.
+#at_exit { RSpec::Puppet::Coverage.report! }
