@@ -9,9 +9,10 @@ describe 'postgresql::lib::java', :type => :class do
       :operatingsystemrelease => '6.0',
     }
     end
-    it { should contain_package('postgresql-jdbc').with(
+    it { is_expected.to contain_package('postgresql-jdbc').with(
       :name   => 'libpostgresql-jdbc-java',
-      :ensure => 'present'
+      :ensure => 'present',
+      :tag    => 'postgresql'
     )}
   end
 
@@ -22,17 +23,19 @@ describe 'postgresql::lib::java', :type => :class do
       :operatingsystemrelease => '6.4',
     }
     end
-    it { should contain_package('postgresql-jdbc').with(
+    it { is_expected.to contain_package('postgresql-jdbc').with(
       :name => 'postgresql-jdbc',
-      :ensure => 'present'
+      :ensure => 'present',
+      :tag    => 'postgresql'
     )}
     describe 'when parameters are supplied' do
       let :params do
         {:package_ensure => 'latest', :package_name => 'somepackage'}
       end
-      it { should contain_package('postgresql-jdbc').with(
+      it { is_expected.to contain_package('postgresql-jdbc').with(
         :name => 'somepackage',
-        :ensure => 'latest'
+        :ensure => 'latest',
+        :tag    => 'postgresql'
       )}
     end
   end
