@@ -7,12 +7,13 @@ describe 'postgresql::repo', :type => :class do
       :operatingsystem        => 'Debian',
       :operatingsystemrelease => '6.0',
       :lsbdistid              => 'Debian',
+      :lsbdistcodename        => 'squeeze',
     }
   end
 
   describe 'with no parameters' do
     it 'should instantiate apt_postgresql_org class' do
-      should contain_class('postgresql::repo::apt_postgresql_org')
+      is_expected.to contain_class('postgresql::repo::apt_postgresql_org')
     end
   end
 end
