@@ -12,6 +12,8 @@ describe 'postgresql::server::contrib', :type => :class do
       :operatingsystemrelease => '6.0',
       :kernel => 'Linux',
       :concat_basedir => tmpfilename('contrib'),
+      :id => 'root',
+      :path => '/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin',
     }
   end
 
@@ -24,7 +26,7 @@ describe 'postgresql::server::contrib', :type => :class do
     end
 
     it 'should create package with correct params' do
-      should contain_package('postgresql-contrib').with({
+      is_expected.to contain_package('postgresql-contrib').with({
         :ensure => 'absent',
         :name => 'mypackage',
         :tag => 'postgresql',
@@ -34,7 +36,7 @@ describe 'postgresql::server::contrib', :type => :class do
 
   describe 'with no parameters' do
     it 'should create package with postgresql tag' do
-      should contain_package('postgresql-contrib').with({
+      is_expected.to contain_package('postgresql-contrib').with({
         :tag => 'postgresql',
       })
     end
