@@ -8,6 +8,8 @@ describe 'postgresql::server::plperl', :type => :class do
       :operatingsystemrelease => '6.0',
       :kernel => 'Linux',
       :concat_basedir => tmpfilename('plperl'),
+      :id => 'root',
+      :path => '/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin',
     }
   end
 
@@ -16,9 +18,9 @@ describe 'postgresql::server::plperl', :type => :class do
   end
 
   describe 'with no parameters' do
-    it { should include_class("postgresql::server::plperl") }
+    it { is_expected.to contain_class("postgresql::server::plperl") }
     it 'should create package' do
-      should contain_package('postgresql-plperl').with({
+      is_expected.to contain_package('postgresql-plperl').with({
         :ensure => 'present',
         :tag => 'postgresql',
       })
@@ -33,9 +35,9 @@ describe 'postgresql::server::plperl', :type => :class do
       }
     end
 
-    it { should include_class("postgresql::server::plperl") }
+    it { is_expected.to contain_class("postgresql::server::plperl") }
     it 'should create package with correct params' do
-      should contain_package('postgresql-plperl').with({
+      is_expected.to contain_package('postgresql-plperl').with({
         :ensure => 'absent',
         :name => 'mypackage',
         :tag => 'postgresql',
