@@ -22,4 +22,10 @@ describe 'postgresql::server::database', :type => :define do
 
   it { is_expected.to contain_postgresql__server__database('test') }
   it { is_expected.to contain_postgresql_psql("Check for existence of db 'test'") }
+
+  context "with comment set to 'test comment'" do
+    let (:params) {{ :comment => 'test comment' }}
+
+    it { is_expected.to contain_postgresql_psql("COMMENT ON DATABASE test IS 'test comment'") }
+  end
 end
