@@ -33,7 +33,7 @@ describe 'postgresql::server::db', :type => :define do
 
     it { is_expected.to contain_postgresql__server__db('test') }
     it { is_expected.to contain_postgresql__server__database('test').with_owner('tester') }
-    it { is_expected.to contain_postgresql__server__role('test') }
+    it { is_expected.to contain_postgresql__server__role('test').that_comes_before('Postgresql::Server::Database[test]') }
     it { is_expected.to contain_postgresql__server__database_grant('GRANT test - ALL - test') }
 
   end
