@@ -6,6 +6,10 @@ describe 'postgresql::server::table_grant', :type => :define do
       :osfamily => 'Debian',
       :operatingsystem => 'Debian',
       :operatingsystemrelease => '6.0',
+      :kernel => 'Linux',
+      :concat_basedir => tmpfilename('table_grant'),
+      :id => 'root',
+      :path => '/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin',
     }
   end
 
@@ -22,6 +26,10 @@ describe 'postgresql::server::table_grant', :type => :define do
     }
   end
 
-  it { should contain_postgresql__server__table_grant('test') }
-  it { should contain_postgresql__server__grant('table:test') }
+  let :pre_condition do
+    "class {'postgresql::server':}"
+  end
+
+  it { is_expected.to contain_postgresql__server__table_grant('test') }
+  it { is_expected.to contain_postgresql__server__grant('table:test') }
 end
